﻿using System;
using System.Windows;
using System.Windows.Input;
using NUnit.Framework;
using System.Collections;

namespace Faz.SideWinderSC.Client
{
    /// <summary>
    /// Tests the <see cref="ConsoleKeyToKeyConverter"/> class.
    /// </summary>
    [TestFixture]
    public class ConsoleKeyToKeyConverterTest
    {
        /// <summary>
        /// Tests the <see cref="ConsoleKeyToKeyConverter.Convert"/> method.
        /// </summary>
        [Test]
        public void Convert()
        {
            ConsoleKeyToKeyConverter instance = new ConsoleKeyToKeyConverter();

            Assert.AreEqual(DependencyProperty.UnsetValue, instance.Convert(null, typeof(Key), null, null));
            Assert.AreEqual(DependencyProperty.UnsetValue, instance.Convert(ConsoleKey.F11, typeof(string), null, null));
            Assert.AreEqual(Key.F11, instance.Convert(ConsoleKey.F11, typeof(Key), null, null));
            Assert.AreEqual(Key.Left, instance.Convert(ConsoleKey.LeftArrow, typeof(Key), null, null));

            CollectionAssert.AreEquivalent(new Key[0], (IEnumerable)instance.Convert(new ConsoleKey[0], typeof(Key), null, null));
            CollectionAssert.AreEquivalent(new[] { Key.F11 }, (IEnumerable)instance.Convert(new[] { ConsoleKey.F11 }, typeof(Key), null, null));
            CollectionAssert.AreEquivalent(new[] { Key.F11, Key.Left }, (IEnumerable)instance.Convert(new[] { ConsoleKey.F11, ConsoleKey.LeftArrow }, typeof(Key), null, null));
        }

        /// <summary>
        /// Tests the <see cref="ConsoleKeyToKeyConverter.ConvertBack"/> method.
        /// </summary>
        [Test]
        public void ConvertBack()
        {
            ConsoleKeyToKeyConverter instance = new ConsoleKeyToKeyConverter();

            Assert.AreEqual(DependencyProperty.UnsetValue, instance.ConvertBack(null, typeof(ConsoleKey), null, null));
            Assert.AreEqual(DependencyProperty.UnsetValue, instance.ConvertBack(Key.F11, typeof(string), null, null));
            Assert.AreEqual(DependencyProperty.UnsetValue, instance.ConvertBack(Key.CapsLock, typeof(ConsoleKey), null, null));
            Assert.AreEqual(ConsoleKey.F11, instance.ConvertBack(Key.F11, typeof(ConsoleKey), null, null));
            Assert.AreEqual(ConsoleKey.LeftArrow, instance.ConvertBack(Key.Left, typeof(ConsoleKey), null, null));

            CollectionAssert.AreEquivalent(new ConsoleKey[0], (IEnumerable)instance.ConvertBack(new Key[0], typeof(ConsoleKey), null, null));
            CollectionAssert.AreEquivalent(new[] { ConsoleKey.F11 }, (IEnumerable)instance.ConvertBack(new[] { Key.F11 }, typeof(ConsoleKey), null, null));
            CollectionAssert.AreEquivalent(new[] { ConsoleKey.F11, ConsoleKey.LeftArrow }, (IEnumerable)instance.ConvertBack(new[] { Key.F11, Key.Left }, typeof(ConsoleKey), null, null));
        }
    }
}
