﻿using System;
using NUnit.Framework;

namespace Faz.SideWinderSC.Client.ViewModel
{
    /// <summary>
    /// Tests the <see cref="Command"/> class.
    /// </summary>
    [TestFixture]
    public class CommandTest
    {
        /// <summary>
        /// Tests the <see cref="Command"/> constructor.
        /// </summary>
        [Test]
        public void Constructor()
        {
            Assert.Throws<ArgumentNullException>(() => new Command(null));
            Assert.Throws<ArgumentNullException>(() => new Command(null, o => true));
        }

        /// <summary>
        /// Tests the <see cref="Command.Execute"/> method.
        /// </summary>
        [Test]
        public void Execute()
        {
            bool executed = false;
            object parameter = null;
            bool canExecute = true;
            Action<object> execute = o => { executed = true; parameter = o; };
            Command instance = new Command(execute, o => canExecute);

            executed = false;
            instance.Execute(null);
            Assert.IsTrue(executed);
            Assert.AreEqual(null, parameter);

            executed = false;
            instance.Execute("unit test");
            Assert.IsTrue(executed);
            Assert.AreEqual("unit test", parameter);

            canExecute = false;
            executed = false;
            instance.Execute(null);
            Assert.IsFalse(executed);
        }

        /// <summary>
        /// Tests the <see cref="Command.CanExecute"/> method.
        /// </summary>
        [Test]
        public void CanExecute()
        {
            object parameter = null;
            bool canExecute = true;
            Func<object, bool> canExecuted = o => { parameter = o; return canExecute; };
            Command instance = new Command(o => { }, canExecuted);

            Assert.IsTrue(instance.CanExecute(null));
            Assert.AreEqual(null, parameter);

            Assert.IsTrue(instance.CanExecute("unit test"));
            Assert.AreEqual("unit test", parameter);

            canExecute = false;
            Assert.IsFalse(instance.CanExecute("unit test 2"));
            Assert.AreEqual("unit test 2", parameter);
        }
    }
}
