﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using NUnit.Framework;
using System.Xml.Serialization;
using System.IO;
using System.Xml;

namespace Faz.SideWinderSC.Logic
{
    /// <summary>
    /// Tests the <see cref="Profile"/> class.
    /// </summary>
    [TestFixture]
    public class ProfileTest
    {
        /// <summary>
        /// Tests the <see cref="Profile.Mappings"/> property.
        /// </summary>
        [Test]
        public static void Mappings()
        {
            Assert.Throws<ArgumentNullException>(() => new Profile(null));

            Model model = new Model() { Name = "Unit Test" };
            Profile profile = new Profile(model);

            Assert.IsNotNull(profile.Mappings);
            Assert.IsFalse(profile.Mappings.IsReadOnly);
            Assert.AreEqual(0, profile.Mappings.Count);
        }

        /// <summary>
        /// Tests the <see cref="Profile.WriteXml"/> method.
        /// </summary>
        [Test]
        public static void WriteXml()
        {
            Model model = new Model() { Name = "Unit Test" };
            Profile instance = new Profile(model);
            instance.Name = "Test Profile";
            instance.Mappings.Add(new Mapping() { Name = "Test Mapping" });

            Assert.Throws<ArgumentNullException>(() => instance.WriteXml(null));

            using (MemoryStream stream = new MemoryStream())
            using (TextReader reader = new StreamReader(stream))
            using (XmlWriter writer = XmlWriter.Create(stream, new XmlWriterSettings() { ConformanceLevel = ConformanceLevel.Fragment }))
            {
                instance.WriteXml(writer);
                writer.Flush();
                stream.Position = 0;
                Assert.AreEqual(
                    "<Profile><Name>Test Profile</Name><Mapping><Name>Test Mapping</Name></Mapping></Profile>",
                    reader.ReadToEnd());
            }
        }

        /// <summary>
        /// Tests the <see cref="Profile.ReadXml"/> method.
        /// </summary>
        [Test]
        public static void ReadXml_Empty()
        {
            Profile instance = new Profile(new Model());

            Assert.Throws<ArgumentNullException>(() => instance.ReadXml(null));

            using (MemoryStream stream = new MemoryStream())
            using (TextWriter writer = new StreamWriter(stream))
            {
                writer.Write("<?xml version=\"1.0\" encoding=\"utf-8\" ?><Profile />");
                writer.Flush();
                stream.Position = 0;
                using (XmlReader reader = XmlReader.Create(stream, new XmlReaderSettings()))
                {
                    instance.ReadXml(reader);
                }

                Assert.AreEqual(null, instance.FilePath);
                Assert.AreEqual(null, instance.Name);
                Assert.IsNotNull(instance.Mappings);
                Assert.AreEqual(0, instance.Mappings.Count);
            }
        }

        /// <summary>
        /// Tests the <see cref="Profile.ReadXml"/> method.
        /// </summary>
        [Test]
        public static void ReadXml_Complete()
        {
            Profile instance = new Profile(new Model());

            using (MemoryStream stream = new MemoryStream())
            using (TextWriter writer = new StreamWriter(stream))
            {
                writer.Write("<Profile><Name>test profile</Name><Mapping><Name>mapping 1</Name></Mapping><Mapping><Name>mapping 2</Name></Mapping></Profile>");
                writer.Flush();
                stream.Position = 0;
                using (XmlReader reader = XmlReader.Create(stream, new XmlReaderSettings()))
                {
                    instance.ReadXml(reader);
                }

                Assert.AreEqual("test profile", instance.Name);
                Assert.IsNotNull(instance.Mappings);
                Assert.AreEqual(2, instance.Mappings.Count);
                Assert.IsNotNull(instance.Mappings.ElementAt(0));
                Assert.IsNotNull(instance.Mappings.ElementAt(1));
                Assert.AreEqual("mapping 1", instance.Mappings.ElementAt(0).Name);
                Assert.AreEqual("mapping 2", instance.Mappings.ElementAt(1).Name);
            }
        }
    }
}
