﻿using System;
using System.Linq;
using System.Reflection;
using NUnit.Framework;

namespace Faz.SideWinderSC.Logic
{
    /// <summary>
    /// Checks the unit tests implementation to find coding issues and prevents errors.
    /// </summary>
    [TestFixture]
    public static class TestAdvisor
    {
        /// <summary>
        /// Tests that all the public classes are marked with the
        /// <see cref="TestFixtureAttribute"/>.
        /// </summary>
        [Test]
        public static void CheckClasses()
        {
            Type[] types = typeof(TestAdvisor).Assembly.GetTypes();
            foreach (Type type in types)
            {
                if (type.IsInterface || type.IsAbstract)
                {
                    continue;
                }

                if (type.IsPublic)
                {
                    // should be a test
                    if (type.GetCustomAttributes(typeof(TestFixtureAttribute), true).Length == 0)
                    {
                        string message = "The public class {0} is not marked with a [TestFixture] attribute";
                        Assert.Fail(message, type.FullName);
                    }

                    // Tests the public methods
                    foreach (MethodInfo method in type.GetMethods(BindingFlags.Public | BindingFlags.Instance | BindingFlags.Static))
                    {
                        if (method.DeclaringType == typeof(object))
                        {
                            continue;
                        }

                        if (!method.GetCustomAttributes(true).Any(c => c.GetType().Namespace == "NUnit.Framework"))
                        {
                            string message = "The public method {0}.{1} is not marked with a [Test] or [TestCase] attribute";
                            Assert.Fail(message, type.FullName, method.Name);
                        }
                    }
                }
                else
                {
                    // should not be a test
                    if (type.GetCustomAttributes(typeof(TestFixtureAttribute), true).Length > 0)
                    {
                        string message = "The non-public class {0} is marked with a [TestFixture] attribute";
                        Assert.Fail(message, type.FullName);
                    }
                }
            }
        }
    }
}
