﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using NUnit.Framework;
using System.Runtime.InteropServices;

namespace Faz.SideWinderSC.Logic.Win32Api
{
    /// <summary>
    /// Tests the <see cref="SetupApiMethods"/> class.
    /// </summary>
    [TestFixture]
    public class SetupApiMethodsTest
    {
        /// <summary>
        /// Tests the <see cref="SetupApiMethods.GetClassDevs"/> method.
        /// </summary>
        [Test]
        public static void GetClassDevs()
        {
            Guid deviceClass = Guid.Parse("4d1e55b2-f16f-11cf-88cb-001111000030");
            using (var actual = SetupApiMethods.GetClassDevs(ref deviceClass, null, IntPtr.Zero, DiGetClassFlags.AllClasses))
            {
                Assert.AreEqual(new Guid("4d1e55b2-f16f-11cf-88cb-001111000030"), deviceClass);
                Assert.IsFalse(actual.IsInvalid);
            }
        }

        /// <summary>
        /// Tests the <see cref="SetupApiMethods.EnumDeviceInterfaces"/> method.
        /// </summary>
        [Test]
        public static void EnumDeviceInterfaces()
        {
            Guid deviceClass = Guid.Parse("4d1e55b2-f16f-11cf-88cb-001111000030");
            using (var deviceSet = SetupApiMethods.GetClassDevs(ref deviceClass, null, IntPtr.Zero, DiGetClassFlags.DeviceInterface))
            {
                DeviceInterfaceData actual = new DeviceInterfaceData();

                Win32Assert.Test(SetupApiMethods.EnumDeviceInterfaces(deviceSet, 0, ref deviceClass, 0, actual));

                Assert.AreEqual(new Guid("4d1e55b2-f16f-11cf-88cb-001111000030"), deviceClass);
                Assert.AreEqual(deviceClass, actual.InterfaceClassGuid);
                Assert.AreEqual(Marshal.SizeOf(actual), actual.Size);
            }
        }

        /// <summary>
        /// Tests the <see cref="SetupApiMethods.GetDeviceInterfaceDetail(SafeDeviceSetHandle,DeviceInterfaceData,IntPtr,uint,ref uint,IntPtr)"/>
        /// and <see cref="SetupApiMethods.GetDeviceInterfaceDetail(SafeDeviceSetHandle,DeviceInterfaceData,ref DeviceInterfaceDetailData,uint,ref uint,IntPtr)"/>
        /// methods.
        /// </summary>
        [Test]
        public static void GetDeviceInterfaceDetail()
        {
            Guid deviceClass = Guid.Parse("4d1e55b2-f16f-11cf-88cb-001111000030");
            using (var deviceSet = SetupApiMethods.GetClassDevs(ref deviceClass, null, IntPtr.Zero, DiGetClassFlags.DeviceInterface | DiGetClassFlags.Present))
            {
                DeviceInterfaceData interfaceData = new DeviceInterfaceData();
                SetupApiMethods.EnumDeviceInterfaces(deviceSet, 0, ref deviceClass, 0, interfaceData);

                // First call retrieve the size of the buffer
                // The result is not check because an error is expected
                uint requiredSize = 0;
                SetupApiMethods.GetDeviceInterfaceDetail(deviceSet, interfaceData, IntPtr.Zero, 0, ref requiredSize, IntPtr.Zero);
                Assert.AreNotEqual(0, requiredSize);

                // Second call - retrieve the data
                DeviceInterfaceDetailData actual = new DeviceInterfaceDetailData();
                actual.Size = 5;
                Win32Assert.Test(SetupApiMethods.GetDeviceInterfaceDetail(deviceSet, interfaceData, ref actual, requiredSize, ref requiredSize, IntPtr.Zero));
                Assert.IsNotNullOrEmpty(actual.DevicePath);
            }
        }
    }
}
