﻿using System;
using System.IO;
using System.Text;
using System.Xml;
using NUnit.Framework;

namespace Faz.SideWinderSC.Logic
{
    /// <summary>
    /// Provides assertion methods for xml elements.
    /// </summary>
    public static class XmlAssert
    {
        /// <summary>
        /// Check whether two xml files have the same content.
        /// </summary>
        /// <param name="expectedFile">The file containing the expected xml.</param>
        /// <param name="actualFile">The file containing the actual xml.</param>
        /// <exception cref="ArgumentNullException">
        /// One of the parameters is <c>null</c>.
        /// </exception>
        public static void AreEqual(string expectedFile, string actualFile)
        {
            if (string.IsNullOrWhiteSpace(expectedFile))
            {
                throw new ArgumentNullException("expectedFile");
            }
            if (string.IsNullOrWhiteSpace(actualFile))
            {
                throw new ArgumentNullException("actualFile");
            }
            if (!File.Exists(expectedFile))
            {
                Assert.Inconclusive("The expected file {0} doesn't exist", expectedFile);
            }
            if (!File.Exists(actualFile))
            {
                Assert.Inconclusive("The actual file {0} doesn't exist", actualFile);
            }

            string expected = ExtractXmlContent(expectedFile);
            string actual = ExtractXmlContent(actualFile);
            Assert.AreEqual(expected, actual);
        }

        /// <summary>
        /// Extracts the xml content of a specified file.
        /// </summary>
        /// <param name="file">The file containing a xml structure</param>
        /// <returns>The xml extracted from the file.</returns>
        private static string ExtractXmlContent(string file)
        {
            XmlWriterSettings settings = new XmlWriterSettings()
            {
                Encoding = Encoding.UTF8,
                Indent = false,
                OmitXmlDeclaration = true,
            };

            StringBuilder builder = new StringBuilder();
            using (XmlWriter writer = XmlWriter.Create(builder, settings))
            {
                XmlDocument document = new XmlDocument();
                document.Load(file);
                document.WriteContentTo(writer);
            }

            return builder.ToString();
        }
    }
}
